( cd usr/lib ; rm -rf libcinepaint_fl_i18n.so.0 )
( cd usr/lib ; ln -sf libcinepaint_fl_i18n.so.0.0.22 libcinepaint_fl_i18n.so.0 )
( cd usr/lib ; rm -rf libcinepaintHalf.so.0 )
( cd usr/lib ; ln -sf libcinepaintHalf.so.0.0.22 libcinepaintHalf.so.0 )
( cd usr/lib ; rm -rf libcinepaint.so )
( cd usr/lib ; ln -sf libcinepaint.so.0.0.22 libcinepaint.so )
( cd usr/lib ; rm -rf libcinepaint_fl_i18n.so )
( cd usr/lib ; ln -sf libcinepaint_fl_i18n.so.0.0.22 libcinepaint_fl_i18n.so )
( cd usr/lib ; rm -rf libcinepaintHalf.so )
( cd usr/lib ; ln -sf libcinepaintHalf.so.0.0.22 libcinepaintHalf.so )
( cd usr/lib ; rm -rf libcinepaint.so.0 )
( cd usr/lib ; ln -sf libcinepaint.so.0.0.22 libcinepaint.so.0 )
