/* LIBCINEPAINT                                                   
 * Copyright (C) 1995-1997 Peter Mattis and Spencer Kimball                
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.             
 *                                                                              
 * This library is distributed in the hope that it will be useful,              
 * but WITHOUT ANY WARRANTY; without even the implied warranty of               
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU            
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */                                                                             
#ifndef __VERSION_H__
#define __VERSION_H__


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


#define PROGRAM_NAME "CinePaint"
#define PROGRAM_LIB_NAME "Lib" PROGRAM_NAME
#define COPYRIGHT "License: GPL with portions LGPL and MIT"
#define LOGO_WIDTH_MIN 350
#define LOGO_HEIGHT_MIN 150

#define MAX_LABEL_LEN 32

#define MAJOR_VERSION				(0)
#define MINOR_VERSION				(22)
#define MICRO_VERSION				(1)
#define PROGRAM_VERSION				"0.22-1"

#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __VERSION_H__ */
